VASP Output Files
--------------------

This module helps with the creation and reading of VASP output files. This module is a fork and refactor of classes used by [PyMatGen](https://github.com/materialsproject/pymatgen/). Specifically, this is a direct alternative to the [`pymatgen.io.vasp.outputs`](https://github.com/materialsproject/pymatgen/blob/master/pymatgen/io/vasp/outputs.py) module. 
